@@ -13,10 +13,12 @@ from __future__ import print_function
 from __future__ import unicode_literals
 
 import os
+import re
 import sys
 import json
 import logging
 import webbrowser
+import warnings
 logging.basicConfig(level=logging.INFO)
 
 # QtAwesome icon fonts for spinners
@@ -73,6 +75,14 @@ def check_if_opensesame_file(filename, os3_only=False):
 		return True
 	return False
 
+class QElidedLabel(QtWidgets.QLabel):
+	""" Label that elides its contents by overwriting paintEvent"""
+	def paintEvent(self, event):
+		painter = QtGui.QPainter(self)
+		metrics = QtGui.QFontMetrics(self.font())
+		elided = metrics.elidedText(self.text(), QtCore.Qt.ElideRight, self.width())
+		painter.drawText(self.rect(), self.alignment(), elided)
+
 class UserBadge(QtWidgets.QWidget):
 	""" A Widget showing the logged in user """
 
@@ -128,8 +138,13 @@ class UserBadge(QtWidgets.QWidget):
 		self.user_button = QtWidgets.QPushButton(self)
 		self.user_button.setIconSize(self.icon_size)
 		self.logged_in_menu = QtWidgets.QMenu(self.login_button)
-		self.logged_in_menu.addAction(_(u"Visit osf.io"), self.__open_osf_website)
-		self.logged_in_menu.addAction(_(u"Log out"), self.__clicked_logout)
+		visit_osf_icon = QtGui.QIcon.fromTheme('web-browser', qta.icon('fa.globe'))
+		self.logged_in_menu.addAction(
+			visit_osf_icon, _(u"Visit osf.io"), self.__open_osf_website)
+		logout_icon = QtGui.QIcon.fromTheme('system-log-out', 
+			qta.icon('fa.sign-out'))
+		self.logged_in_menu.addAction(logout_icon, _(u"Log out"), 
+			self.__clicked_logout)
 		self.user_button.setMenu(self.logged_in_menu)
 		self.user_button.hide()
 		self.user_button.setFlat(True)
@@ -148,8 +163,8 @@ class UserBadge(QtWidgets.QWidget):
 
 		self.login_button.setContentsMargins(0, 0, 0, 0)
 		self.user_button.setContentsMargins(0, 0, 0, 0)
-		self.setContentsMargins(0, 0, 0, 0)
 		self.layout().setContentsMargins(0, 0, 0, 0)
+		self.layout().setSpacing(0)
 
 	def current_user(self):
 		""" Checks the current status of the user.
@@ -217,9 +232,12 @@ class UserBadge(QtWidgets.QWidget):
 
 	def __set_user_photo(self, reply):
 		""" Sets the photo of the user in the userbadge """
-		avatar_img = reply.readAll().data()
-		pixmap = QtGui.QPixmap()
-		pixmap.loadFromData(avatar_img)
+		avatar_data = reply.readAll().data()
+		avatar_img = QtGui.QImage()
+		success = avatar_img.loadFromData(avatar_data)
+		if not success:
+			warnings.warn("Could not load user's profile picture")
+		pixmap = QtGui.QPixmap.fromImage(avatar_img)
 		self.user_button.setIcon(QtGui.QIcon(pixmap))
 
 class OSFExplorer(QtWidgets.QWidget):
@@ -259,17 +277,17 @@ class OSFExplorer(QtWidgets.QWidget):
 		self.setWindowTitle(_("Project explorer"))
 		self.resize(800,500)
 		# Set Window icon
-		if not os.path.isfile(osf_logo_path):
+		if not os.path.isfile(osf_blacklogo_path):
 			raise IOError("OSF logo not found at expected path: {}".format(
-				osf_logo_path))
-		osf_icon = QtGui.QIcon(osf_logo_path)
+				osf_blacklogo_path))
+		osf_icon = QtGui.QIcon(osf_blacklogo_path)
 		self.setWindowIcon(osf_icon)
 
 		# Set up the title widget (so much code for a simple header with image...)
 		self.title_widget = QtWidgets.QWidget(self)
 		self.title_widget.setLayout(QtWidgets.QHBoxLayout(self))
 		title_logo = QtWidgets.QLabel(self)
-		title_logo.setPixmap(osf_icon.pixmap(QtCore.QSize(50,50)))
+		title_logo.setPixmap(osf_icon.pixmap(QtCore.QSize(32,32)))
 		title_label = QtWidgets.QLabel("<h1>Open Science Framework</h1>", self)
 		self.title_widget.layout().addWidget(title_logo)
 		self.title_widget.layout().addWidget(title_label)
@@ -371,6 +389,7 @@ class OSFExplorer(QtWidgets.QWidget):
 		self.main_layout.addWidget(self.title_widget)
 		self.main_layout.addWidget(content_pane)
 		self.main_layout.addWidget(self.buttonbar)
+		self.main_layout.setContentsMargins(12, 12, 12, 12)
 		self.setLayout(self.main_layout)
 
 		# Event connections
@@ -379,7 +398,6 @@ class OSFExplorer(QtWidgets.QWidget):
 		self.tree.refreshFinished.connect(self.__tree_refresh_finished)
 
 	### Private functions
-
 	def __resizeImagePreview(self, event):
 		""" Resize the image preview (if there is any) after a resize event """
 		if not self.current_img_preview is None:
@@ -421,7 +439,7 @@ class OSFExplorer(QtWidgets.QWidget):
 		self.new_folder_button.setDisabled(True)
 
 		self.delete_icon = QtGui.QIcon.fromTheme(
-			'user-trash-symbolic',
+			'edit-delete',
 			qta.icon('fa.trash')
 		)
 		self.delete_button = QtWidgets.QPushButton(self.delete_icon, _('Delete'))
@@ -494,13 +512,19 @@ class OSFExplorer(QtWidgets.QWidget):
 		labelStyle = 'font-weight: bold'
 
 		self.common_fields = ['Name','Type']
-		self.file_fields = ['Size','Created','Modified']
+		self.file_fields = ['Size','Created','Modified','Link']
 
 		self.properties = {}
 		for field in self.common_fields + self.file_fields:
 			label = QtWidgets.QLabel(_(field))
 			label.setStyleSheet(labelStyle)
-			value = QtWidgets.QLabel('')
+			if field == "Link":
+				# Initialize label with some HTML to trigger the rich text mode
+				value = QtWidgets.QLabel('<a></a>')
+				value.setOpenExternalLinks(True)
+			else:
+				value = QElidedLabel('')
+				value.setWindowFlags(QtCore.Qt.Dialog)
 			self.properties[field] = (label,value)
 			properties_pane.addRow(label,value)
 
@@ -508,7 +532,6 @@ class OSFExplorer(QtWidgets.QWidget):
 		for row in self.file_fields:
 			for field in self.properties[row]:
 				field.hide()
-
 		return properties_pane
 
 	### Public functions
@@ -537,12 +560,17 @@ class OSFExplorer(QtWidgets.QWidget):
 
 		# Actions only allowd on files
 		if kind == "file":
-			menu.addAction(self.download_icon, _(u"Download file"), self._clicked_download_file)
+			menu.addAction(self.download_icon, _(u"Download file"), 
+				self._clicked_download_file)
 
 		# Actions only allowed on folders
 		if kind == "folder":
-			menu.addAction(self.upload_icon, _(u"Upload file to folder"), self.__clicked_upload_file)
-			menu.addAction(self.new_folder_icon, _(u"Create new folder"), self.__clicked_new_folder)
+			menu.addAction(self.upload_icon, _(u"Upload file to folder"), 
+				self.__clicked_upload_file)
+			menu.addAction(self.new_folder_icon, _(u"Create new folder"), 
+				self.__clicked_new_folder)
+			menu.addAction(self.refresh_icon, _(u"Refresh contents"), 
+				self.__clicked_partial_refresh)
 
 		# Only allow deletion of files and subfolders of repos
 		if kind == "file" or not item_is_repo:
@@ -686,6 +714,37 @@ class OSFExplorer(QtWidgets.QWidget):
 			for field in self.properties[row]:
 				field.show()
 
+		# Get the link to the file on the website of OSF. This is not readily
+		# available from the returned API data, but can be parsed from the
+		# comments URL, of which it is the [target] filter parameter
+		# Sadly, this is URL is not always available for all files, so hide the
+		# row if parsing fails.
+		try:
+			comments_url = data["relationships"]["comments"]["links"]["related"]\
+				["href"]
+		except KeyError as e:
+			warnings.warn('Could not retrieve comments url, because of missing field {}'.format(e))
+			self.properties["Link"][0].hide()
+			self.properties["Link"][1].hide()
+		else:
+			# Use regular expression to search for the relevant part of the url
+			try:
+				target = re.search('filter\[target\]\=\w+', comments_url).group(0)
+			except AttributeError:
+				# If this didn't work, hide the row altogether
+				self.properties["Link"][0].hide()
+				self.properties["Link"][1].hide()
+			else:
+				# Get the ID part of the filter parameter and generate the url
+				web_id = target.split("=")[1]
+				web_url = u"{}/{}".format(osf.settings['website_url'], web_id)
+				a = u"<a href=\"{0}\">{0}</a>".format(web_url)
+				# Set the URL in the field
+				self.properties["Link"][1].setText(a)
+				# Show the row
+				self.properties["Link"][0].show()
+				self.properties["Link"][1].show()
+
 	def set_folder_properties(self, data):
 		"""
 		Fills the contents of the properties pane for folders. Make sure the
@@ -701,7 +760,11 @@ class OSFExplorer(QtWidgets.QWidget):
 		# A node (i.e. a project) has title and category fields
 		if "title" in attributes and "category" in attributes:
 			self.properties["Name"][1].setText(attributes["title"])
-			self.properties["Type"][1].setText(attributes["category"])
+			if attributes["public"]:
+				level = "Public"
+			else:
+				level = "Private"
+			self.properties["Type"][1].setText(level + " " + attributes["category"])
 		elif "name" in attributes and "kind" in attributes:
 			self.properties["Name"][1].setText(attributes["name"])
 			self.properties["Type"][1].setText(attributes["kind"])
@@ -780,7 +843,11 @@ class OSFExplorer(QtWidgets.QWidget):
 		data = item.data(0, QtCore.Qt.UserRole)
 		if data['type'] == 'nodes':
 			name = data["attributes"]["title"]
-			kind = data["attributes"]["category"]
+			if data["attributes"]["public"]:
+				access = "public "
+			else:
+				access = "private "
+			kind = access + data["attributes"]["category"]
 		if data['type'] == 'files':
 			name = data["attributes"]["name"]
 			kind = data["attributes"]["kind"]
@@ -846,6 +913,17 @@ class OSFExplorer(QtWidgets.QWidget):
 		self.refresh_button.setIcon(self.refresh_icon_spinning)
 		self.tree.refresh_contents()
 
+	def __clicked_partial_refresh(self):
+		selected_item = self.tree.currentItem()
+		# Don't do anything if the refresh button is disabled. This probably
+		# means a refresh operation is in progress, and activating another one
+		# during this is asking for trouble.
+		if self.refresh_button.isEnabled() == False:
+			return
+		self.refresh_button.setDisabled(True)
+		self.refresh_button.setIcon(self.refresh_icon_spinning)
+		self.tree.refresh_children_of_node(selected_item)
+
 	def _clicked_download_file(self):
 		""" Action to be performed when download button is clicked. Downloads the
 		selected file to the user specified location. """
@@ -948,6 +1026,16 @@ class OSFExplorer(QtWidgets.QWidget):
 			# If index_is_present is a number, it means the file is present
 			# and that file needs to be updated.
 			else:
+				reply = QtWidgets.QMessageBox.question(
+					self,
+					_("Please confirm"),
+					_("The selected folder already contains this file. Are you "
+						"sure you want to overwrite it?"),
+					QtWidgets.QMessageBox.No | QtWidgets.QMessageBox.Yes
+				)
+				if reply == QtWidgets.QMessageBox.No:
+					return
+
 				logging.info("File {} exists and will be updated".format(filename))
 				old_item = selected_item.child(index_if_present)
 				# Get data stored in item
@@ -985,7 +1073,7 @@ class OSFExplorer(QtWidgets.QWidget):
 			return
 
 		# Remove illegal filesystem characters (mainly for Windows)
-		new_folder_name = "".join(i for i in new_folder_name if i not in r'\/:*?"<>|')
+		new_folder_name = u"".join(i for i in new_folder_name if i not in r'\/:*?"<>|')
 		# Check again
 		if not len(new_folder_name):
 			return
@@ -1032,35 +1120,36 @@ class OSFExplorer(QtWidgets.QWidget):
 					new_item_data['data']['attributes']['path'])
 			# All other repo's are a bit more difficult...
 			else:
-				# Don't even bother for folders and simple refresh the whole tree
+				# Don't even bother for folders and simply refresh the tree.
+				# OSF does not provide possibility to get folder information (in
+				# contrast to folder contents) for newly created folders in external
+				# repositories
 				if new_item_data['data']['attributes']['kind'] == 'folder':
+					kwargs['entry_node'] = selectedTreeItem
 					self.__upload_refresh_tree(*args, **kwargs)
 					return
 
 				# If kind is a file, try to add it to the tree incrementally
 				# (thus without refreshing the whole tree). At the moment, this
 				# only works well for osfstorage...
-				node_data = selectedTreeItem.data(0,QtCore.Qt.UserRole)
-				node_id = node_data['id']
-				# Protocol for direct repository entries is a bit different than for
-				# subfolders
-				if ':' in node_id:
-					project_id, repo = node_id.split(':')
-					info_url = osf.api_call('repo_files', project_id, new_item_data['data']['id'])
-					# Remove trailing slash, as it in this case throws off osf api
-					if info_url[-1] == u"/":
-						info_url = info_url[:-1]
-				else:
-					### Files uploaded to subfolders don't work well yet, because OSF
-					## returns a crappy upload response. Simply refresh the whole tree
-					# info_url = osf.api_call('file_info',
-					# 	new_item_data['data']['attributes']['path'])
-					self.__upload_refresh_tree(*args, **kwargs)
-					return
+				try:
+					project_id = new_item_data['data']['attributes']['resource']
+					temp_id = new_item_data['data']['id']
+				except KeyError as e:
+					raise osf.OSFInvalidResponse(
+						u'Could not parse provider from OSF response: {}'.format(e))
+
+				# Create an url for this file with which the complete information
+				# set can be retrieved
+				info_url = osf.api_call('repo_files', project_id, temp_id)
+				
+				# The repo_files api call adds a trailing slash, but this is invalid
+				# when requesting information about files. Remove it if present.
+				if info_url[-1] == u"/":
+					info_url = info_url[:-1]
 
 			# Refresh info for the new file as the returned representation
 			# is incomplete
-			kwargs['new_item_data'] = new_item_data
 
 			self.manager.get(
 				info_url,
@@ -1072,7 +1161,17 @@ class OSFExplorer(QtWidgets.QWidget):
 	def __upload_refresh_tree(self, *args, **kwargs):
 		""" Called by _upload_finished() if the whole tree needs to be
 		refreshed """
-		self.__clicked_refresh_tree()
+
+		# If an entry node is specified, only refresh the children of that node,
+		# otherwise, refresh entire tree
+		entry_node = kwargs.pop('entry_node', None)
+		if entry_node is None:
+			self.__clicked_refresh_tree()
+		else:
+			self.refresh_button.setDisabled(True)
+			self.refresh_button.setIcon(self.refresh_icon_spinning)
+			self.tree.refresh_children_of_node(entry_node)	
+
 		after_upload_cb = kwargs.pop('afterUploadCallback', None)
 		if callable(after_upload_cb):
 			after_upload_cb(*args, **kwargs)
@@ -1086,7 +1185,11 @@ class OSFExplorer(QtWidgets.QWidget):
 		updateIndex = kwargs.get('updateIndex')
 		if not updateIndex is None:
 			parent_item.takeChild(updateIndex)
+		# Add the item as a new item to the tree
 		new_item, kind = self.tree.add_item(parent_item, item['data'])
+		# Set new item as currently selected item
+		self.tree.setCurrentItem(new_item)
+		# Store item in kwargs so callback functions can use it
 		kwargs['new_item'] = new_item
 		# Perform the afterUploadCallback if it has been specified
 		after_upload_cb = kwargs.pop('afterUploadCallback', None)
@@ -1096,7 +1199,12 @@ class OSFExplorer(QtWidgets.QWidget):
 	def __item_deleted(self, reply, item):
 		""" Callback for when an item has been successfully deleted from the OSF.
 		Removes the item from the tree. """
-		item.parent().removeChild(item)
+		# See if object is still alive (could be deleted after user has had
+		# to reauthenticate)
+		try:
+			item.parent().removeChild(item)
+		except RuntimeError as e:
+			warnings.warn("Deleting item failed: {}".format(e))
 
 	def __tree_refresh_finished(self):
 		""" Slot for the event fired when the tree refresh is finished """
@@ -1249,8 +1357,10 @@ class ProjectTree(QtWidgets.QTreeWidget):
 			item.setIcon(0,self.get_icon('folder',data['attributes']['name']))
 		self.expanded_items.discard(data['id'])
 
-	def __populate_error(self, reply):
-		""" Callback for when an error occured while populating the tree. """
+	def __cleanup_reply(self, reply):
+		""" Callback for when an error occured while populating the tree, or when
+		populate_tree finished successfully. Removes the QNetworkReply
+		from the list of active HTTP operations. """
 		# Reset active requests after error
 		try:
 			self.active_requests.remove(reply)
@@ -1405,7 +1515,7 @@ class ProjectTree(QtWidgets.QTreeWidget):
 		QtGui.QIcon : The icon for the current file/object type """
 
 		providers = {
-			'osfstorage'   : osf_logo_path,
+			'osfstorage'   : osf_blacklogo_path,
 			'github'       : 'web-github',
 			'dropbox'      : 'dropbox',
 			'googledrive'  : 'web-google-drive',
@@ -1416,11 +1526,20 @@ class ProjectTree(QtWidgets.QTreeWidget):
 			's3'           : 'web-microsoft-onedrive',
 		}
 
-		if datatype == 'project':
-			return QtGui.QIcon.fromTheme(
-				'gbrainy',
-				QtGui.QIcon(osf_logo_path)
-			)
+		if datatype.lower() in ['public project','private project']:
+			# return QtGui.QIcon.fromTheme(
+			# 	'gbrainy',
+			# 	QtGui.QIcon(osf_logo_path)
+			# )
+			if datatype.lower() == 'public project':
+				return qta.icon('fa.cube', 'fa.globe',
+					options=[
+						{},
+						{'scale_factor': 0.75,
+						'offset': (0.2, 0.20),
+						'color': 'green'}])
+			else:
+				return qta.icon('fa.cube')
 
 		if datatype in ['folder','folder-open']:
 			# Providers are also seen as folders, so if the current folder
@@ -1428,12 +1547,12 @@ class ProjectTree(QtWidgets.QTreeWidget):
 			if name in providers:
 				return QtGui.QIcon.fromTheme(
 					providers[name],
-					QtGui.QIcon(osf_logo_path)
+					QtGui.QIcon(osf_blacklogo_path)
 				)
 			else:
 				return QtGui.QIcon.fromTheme(
 					datatype,
-					QtGui.QIcon(osf_logo_path)
+					QtGui.QIcon(osf_blacklogo_path)
 				)
 		elif datatype == 'file':
 			# check for OpenSesame extensions first. If this is not an OS file
@@ -1447,13 +1566,62 @@ class ProjectTree(QtWidgets.QTreeWidget):
 				filetype,
 				QtGui.QIcon.fromTheme(
 					'text-x-generic',
-					QtGui.QIcon('osf_logo_path')
+					QtGui.QIcon(osf_blacklogo_path)
 				)
 			)
-		return QtGui.QIcon(osf_logo_path)
+		return QtGui.QIcon(osf_blacklogo_path)
+
+	def refresh_children_of_node(self, node):
+		""" In contrast to refresh_contents, which refreshes the whole tree from
+		the root, this function only refreshes the children of the passed node.
+
+		Parameters
+		----------
+		node : QtWidgets.QTreeWidgetItem
+			The tree item of which the children need to be refreshed.
+		"""
+		if not isinstance(node, QtWidgets.QTreeWidgetItem):
+			raise TypeError('node is not a tree widget item')
+
+		# If tree currently is refreshing, do nothing
+		if self.isRefreshing == True:
+			return
+		# Set flag that tree is currently refreshing
+		self.isRefreshing = True
+
+		try:
+			node_data = node.data(0, QtCore.Qt.UserRole)
+		except RuntimeError as e:
+			warnings.warn('Partial refresh attempted while tree item was already'
+				' deleted')
+			self.isRefreshing = False
+			return
+
+		try:
+			content_url = node_data['relationships']['files']['links'] \
+				['related']['href']
+		except KeyError as e:
+			self.isRefreshing = False
+			raise osf.OSFInvalidResponse('Invalid structure of tree item data '
+				': {}'.format(e))
+
+		# Delete the current children of the node to make place for the new ones
+		node.takeChildren()
+
+		# Retrieve the new listing of children from the OSF
+		req = self.manager.get(
+			content_url,
+			self.populate_tree,
+			node,
+			errorCallback=self.__cleanup_reply
+		)
+
+		# If something went wrong, req should be None
+		if req:
+			self.active_requests.append(req)
 
 	def refresh_contents(self):
-		""" Refreshes the contents of the tree """
+		""" Refreshes all content of the tree """
 		# If tree is already refreshing, don't start again, as this will result
 		# in a crash
 		if self.isRefreshing == True:
@@ -1475,15 +1643,21 @@ class ProjectTree(QtWidgets.QTreeWidget):
 			# If not, query the osf for the user data, and pass get_repo_contents
 			# ass the callback to which the received data should be sent.
 			self.manager.get_logged_in_user(
-				self.process_repo_contents, errorCallback=self.__populate_error)
+				self.process_repo_contents, errorCallback=self.__cleanup_reply)
 
 	def add_item(self, parent, data):
 		if data['type'] == 'nodes':
 			name = data["attributes"]["title"]
+			if data["attributes"]["public"]:
+				access = "public "
+			else:
+				access = "private "
 			kind = data["attributes"]["category"]
+			icon_type = access + kind
 		if data['type'] == 'files':
 			name = data["attributes"]["name"]
 			kind = data["attributes"]["kind"]
+			icon_type = kind
 
 		values = [name, kind]
 		if "size" in data["attributes"] and data["attributes"]["size"]:
@@ -1493,7 +1667,7 @@ class ProjectTree(QtWidgets.QTreeWidget):
 		item = QtWidgets.QTreeWidgetItem(parent, values)
 
 		# Set icon
-		icon = self.get_icon(kind, name)
+		icon = self.get_icon(icon_type, name)
 		item.setIcon(0, icon)
 
 		# Add data
@@ -1513,7 +1687,7 @@ class ProjectTree(QtWidgets.QTreeWidget):
 		----------
 		reply : QtNetwork.QNetworkReply
 			The data from the OSF to create the node in the tree for.
-		parent : QtWidgets.QTreeWidgetItem (options)
+		parent : QtWidgets.QTreeWidgetItem (default: None)
 			The parent item to which the generated tree should be attached.
 			Is mainly used for the recursiveness that this function implements.
 			If not specified the invisibleRootItem() is used as a parent.
@@ -1528,8 +1702,17 @@ class ProjectTree(QtWidgets.QTreeWidget):
 			parent = self.invisibleRootItem()
 
 		for entry in osf_response["data"]:
-			# Add item to the tree
-			item, kind = self.add_item(parent, entry)
+			# Add item to the tree. Check if object hasn't been deleted in the
+			# meantime
+			try:
+				item, kind = self.add_item(parent, entry)
+			except RuntimeError as e:
+				# If a runtime error occured the tree was probably reset or 
+				# another event  deleted treeWidgetItems. Not much that can be
+				# done here, so do some cleanup and quit
+				warnings.warn(e)
+				self.__cleanup_reply(reply)
+				return
 
 			if kind in ["project","folder"]:
 				try:
@@ -1545,7 +1728,7 @@ class ProjectTree(QtWidgets.QTreeWidget):
 					next_entrypoint,
 					self.populate_tree,
 					item,
-					errorCallback=self.__populate_error
+					errorCallback=self.__cleanup_reply
 				)
 				# If something went wrong, req should be None
 				if req:
@@ -1564,20 +1747,14 @@ class ProjectTree(QtWidgets.QTreeWidget):
 				next_page_url,
 				self.populate_tree,
 				parent,
-				errorCallback=self.__populate_error
+				errorCallback=self.__cleanup_reply
 			)
 			# If something went wrong, req should be None
 			if req:
 				self.active_requests.append(req)
 
 		# Remove current reply from list of active requests (assuming it finished)
-		try:
-			self.active_requests.remove(reply)
-		except ValueError:
-			logging.info("Reply not found in active requests")
-
-		if not self.active_requests:
-			self.refreshFinished.emit()
+		self.__cleanup_reply(reply)
 
 	def process_repo_contents(self, logged_in_user):
 		""" Processes contents for the logged in user. Starts by listing
@@ -1604,7 +1781,7 @@ class ProjectTree(QtWidgets.QTreeWidget):
 		req = self.manager.get(
 			user_nodes_api_call,
 			self.populate_tree,
-			errorCallback=self.__populate_error,
+			errorCallback=self.__cleanup_reply,
 		)
 		# If something went wrong, req should be None
 		if req:
